==> jc-1.4.0.tar.gz: java/rmi/activation/ActivationGroup.h <==
// public abstract class java.rmi.activation.ActivationGroup

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6152d3f7d66cc3a7 java_rmi_activation_ActivationGroup
// @dep_class 46051fa019dc720f java_rmi_server_RemoteObject
// @dep_class 1c165ce24effd6b java_rmi_server_RemoteServer
// @dep_class 719785c1fd5bba70 java_rmi_server_UnicastRemoteObject

// header file dependencies
// @dep_header java_rmi_server_UnicastRemoteObject

#include "java/rmi/server/UnicastRemoteObject.h"

#ifndef _JC_java_rmi_activation_ActivationGroup_H_
#define _JC_java_rmi_activation_ActivationGroup_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_MarshalledObject$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_activation_ActivationGroup$object;
struct _jc_java_rmi_activation_ActivationGroupDesc$object;
struct _jc_java_rmi_activation_ActivationGroupID$object;
struct _jc_java_rmi_activation_ActivationID$object;
struct _jc_java_rmi_activation_ActivationSystem$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationGroup$sub_refs	_jc_java_rmi_activation_ActivationGroup$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationGroup$sub_nonrefs	_jc_java_rmi_activation_ActivationGroup$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroup$refs	_jc_java_rmi_activation_ActivationGroup$refs;
typedef struct _jc_java_rmi_activation_ActivationGroup$nonrefs	_jc_java_rmi_activation_ActivationGroup$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroup$object	_jc_java_rmi_activation_ActivationGroup$object;

typedef struct _jc_java_rmi_activation_ActivationGroup$fields_struct	_jc_java_rmi_activation_ActivationGroup$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationGroup$vmethods	_jc_java_rmi_activation_ActivationGroup$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationGroup$vtable	_jc_java_rmi_activation_ActivationGroup$vtable;
typedef const struct _jc_java_rmi_activation_ActivationGroup$vtype	_jc_java_rmi_activation_ActivationGroup$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationGroup$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationGroup$fields_struct _jc_java_rmi_activation_ActivationGroup$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationGroup$method$_init$6df86cd224d1f5b5(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationGroupID$object *);

// Virtual methods
extern void _jc_java_rmi_activation_ActivationGroup$method$activeObject$1a5d95fb822bd679(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_java_rmi_MarshalledObject$object *);
extern void _jc_java_rmi_activation_ActivationGroup$method$activeObject$9a23697c7c73b0fa(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_object *);
extern void _jc_java_rmi_activation_ActivationGroup$method$inactiveGroup$c32c6239e8eaedbd(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *);
extern jboolean _jc_java_rmi_activation_ActivationGroup$method$inactiveObject$3816055e0f98e007(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationGroup$method_info$activeObject$1a5d95fb822bd679;
extern _jc_method _jc_java_rmi_activation_ActivationGroup$method_info$activeObject$9a23697c7c73b0fa;
extern _jc_method _jc_java_rmi_activation_ActivationGroup$method_info$inactiveGroup$c32c6239e8eaedbd;
extern _jc_method _jc_java_rmi_activation_ActivationGroup$method_info$inactiveObject$3816055e0f98e007;

// Static methods
extern struct _jc_java_rmi_activation_ActivationGroup$object *_jc_java_rmi_activation_ActivationGroup$method$createGroup$51d29d8b90a50a6b(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *, struct _jc_java_rmi_activation_ActivationGroupDesc$object *, jlong);
extern struct _jc_java_rmi_activation_ActivationGroupID$object *_jc_java_rmi_activation_ActivationGroup$method$currentGroupID$cf4066a07599e1c4(_jc_env *);
extern struct _jc_object *_jc_java_rmi_activation_ActivationGroup$method$getSystem$31603400e2ddfccb(_jc_env *);
extern void _jc_java_rmi_activation_ActivationGroup$method$setSystem$d95189d88e67caf5(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationGroup$vmethods {
	void	(*activeObject$1a5d95fb822bd679)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_java_rmi_MarshalledObject$object *);
	void	(*activeObject$9a23697c7c73b0fa)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_object *);
	void	(*inactiveGroup$c32c6239e8eaedbd)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *);
	jboolean	(*inactiveObject$3816055e0f98e007)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *);
};

// Vtable
struct _jc_java_rmi_activation_ActivationGroup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteServer$vmethods	java_rmi_server_RemoteServer;
	_jc_java_rmi_server_UnicastRemoteObject$vmethods	java_rmi_server_UnicastRemoteObject;
	_jc_java_rmi_activation_ActivationGroup$vmethods	java_rmi_activation_ActivationGroup;
};

// Vtype
struct _jc_java_rmi_activation_ActivationGroup$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationGroup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroup$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroup$refs {
    _jc_java_rmi_activation_ActivationGroup$sub_refs	java_rmi_activation_ActivationGroup;
    _jc_java_rmi_server_UnicastRemoteObject$sub_refs	java_rmi_server_UnicastRemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_refs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_nonrefs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs	java_rmi_server_UnicastRemoteObject;
    _jc_java_rmi_activation_ActivationGroup$sub_nonrefs	java_rmi_activation_ActivationGroup;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationGroup$object {
	_jc_java_rmi_activation_ActivationGroup$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationGroup$vtype	*vtype;
	_jc_java_rmi_activation_ActivationGroup$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationGroup$vtype _jc_java_rmi_activation_ActivationGroup$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationGroup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationGroup$class_object;

#endif	/* _JC_java_rmi_activation_ActivationGroup_H_ */

==> jc-1.4.6.tar.gz: java/rmi/activation/ActivationGroup.h <==
// public abstract class java.rmi.activation.ActivationGroup

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6152d3f7d66cc3a7 java_rmi_activation_ActivationGroup
// @dep_class 8c9f90d92f098cf3 java_rmi_server_RemoteObject
// @dep_class 1c165ce24effd6b java_rmi_server_RemoteServer
// @dep_class 719785c1fd5bba70 java_rmi_server_UnicastRemoteObject

// header file dependencies
// @dep_header java_rmi_server_UnicastRemoteObject

#include "java/rmi/server/UnicastRemoteObject.h"

#ifndef _JC_java_rmi_activation_ActivationGroup_H_
#define _JC_java_rmi_activation_ActivationGroup_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_rmi_MarshalledObject$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_activation_ActivationGroup$object;
struct _jc_java_rmi_activation_ActivationGroupDesc$object;
struct _jc_java_rmi_activation_ActivationGroupID$object;
struct _jc_java_rmi_activation_ActivationID$object;
struct _jc_java_rmi_activation_ActivationSystem$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationGroup$sub_refs	_jc_java_rmi_activation_ActivationGroup$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationGroup$sub_nonrefs	_jc_java_rmi_activation_ActivationGroup$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroup$refs	_jc_java_rmi_activation_ActivationGroup$refs;
typedef struct _jc_java_rmi_activation_ActivationGroup$nonrefs	_jc_java_rmi_activation_ActivationGroup$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationGroup$object	_jc_java_rmi_activation_ActivationGroup$object;

typedef struct _jc_java_rmi_activation_ActivationGroup$fields_struct	_jc_java_rmi_activation_ActivationGroup$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationGroup$vmethods	_jc_java_rmi_activation_ActivationGroup$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationGroup$vtable	_jc_java_rmi_activation_ActivationGroup$vtable;
typedef const struct _jc_java_rmi_activation_ActivationGroup$vtype	_jc_java_rmi_activation_ActivationGroup$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationGroup$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationGroup$fields_struct _jc_java_rmi_activation_ActivationGroup$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationGroup$method$_init$6df86cd224d1f5b5(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationGroupID$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_rmi_activation_ActivationGroup$method$activeObject$1a5d95fb822bd679(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_java_rmi_MarshalledObject$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_activation_ActivationGroup$method$activeObject$9a23697c7c73b0fa(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_activation_ActivationGroup$method$inactiveGroup$c32c6239e8eaedbd(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_rmi_activation_ActivationGroup$method$inactiveObject$3816055e0f98e007(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationGroup$method_info$activeObject$1a5d95fb822bd679;
extern _jc_method _jc_java_rmi_activation_ActivationGroup$method_info$activeObject$9a23697c7c73b0fa;
extern _jc_method _jc_java_rmi_activation_ActivationGroup$method_info$inactiveGroup$c32c6239e8eaedbd;
extern _jc_method _jc_java_rmi_activation_ActivationGroup$method_info$inactiveObject$3816055e0f98e007;

// Static methods
extern struct _jc_java_rmi_activation_ActivationGroup$object *_jc_java_rmi_activation_ActivationGroup$method$createGroup$51d29d8b90a50a6b(_jc_env *, struct _jc_java_rmi_activation_ActivationGroupID$object *, struct _jc_java_rmi_activation_ActivationGroupDesc$object *, jlong) _JC_JCNI_ATTR;
extern struct _jc_java_rmi_activation_ActivationGroupID$object *_jc_java_rmi_activation_ActivationGroup$method$currentGroupID$cf4066a07599e1c4(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_activation_ActivationGroup$method$getSystem$31603400e2ddfccb(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_activation_ActivationGroup$method$setSystem$d95189d88e67caf5(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationGroup$vmethods {
	void	(*activeObject$1a5d95fb822bd679)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_java_rmi_MarshalledObject$object *) _JC_JCNI_ATTR;
	void	(*activeObject$9a23697c7c73b0fa)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*inactiveGroup$c32c6239e8eaedbd)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *) _JC_JCNI_ATTR;
	jboolean	(*inactiveObject$3816055e0f98e007)(_jc_env *, struct _jc_java_rmi_activation_ActivationGroup$object *, struct _jc_java_rmi_activation_ActivationID$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_activation_ActivationGroup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteServer$vmethods	java_rmi_server_RemoteServer;
	_jc_java_rmi_server_UnicastRemoteObject$vmethods	java_rmi_server_UnicastRemoteObject;
	_jc_java_rmi_activation_ActivationGroup$vmethods	java_rmi_activation_ActivationGroup;
};

// Vtype
struct _jc_java_rmi_activation_ActivationGroup$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationGroup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroup$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroup$refs {
    _jc_java_rmi_activation_ActivationGroup$sub_refs	java_rmi_activation_ActivationGroup;
    _jc_java_rmi_server_UnicastRemoteObject$sub_refs	java_rmi_server_UnicastRemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_refs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationGroup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationGroup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_nonrefs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs	java_rmi_server_UnicastRemoteObject;
    _jc_java_rmi_activation_ActivationGroup$sub_nonrefs	java_rmi_activation_ActivationGroup;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationGroup$object {
	_jc_java_rmi_activation_ActivationGroup$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationGroup$vtype	*vtype;
	_jc_java_rmi_activation_ActivationGroup$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationGroup$vtype _jc_java_rmi_activation_ActivationGroup$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationGroup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationGroup$class_object;

#endif	/* _JC_java_rmi_activation_ActivationGroup_H_ */
